@@ -57,7 +57,7 @@ ols_cooksd_barplot <- function(model) {
 	
 	suppressWarnings(print(p))
 	colnames(f) <- c("Observation", "Cook's Distance")
-	result <- list(outliers = f, threshold = round(k$ts, 3))
+	result <- list(outliers = f, threshold = k$ts)
 	invisible(result)
 
 }
\ No newline at end of file
